<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
/*
Plugin Name: Spam Ban
Description: Yorumlarda kullanıcıları banla ve banlanan kullanıcıları yönet.
Version: 1.0
Author: Your Name
*/

// Ban listesi için veritabanı tablosu oluşturma
function sb_create_banlist_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'sb_banlist';
    $charset_collate = $wpdb->get_charset_collate();

    $sql = "CREATE TABLE $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        user_email varchar(100) NOT NULL,
        user_ip varchar(100) NOT NULL,
        attempt_count int(11) NOT NULL DEFAULT 0,
        banned_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
        PRIMARY KEY  (id)
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}

register_activation_hook(__FILE__, 'sb_create_banlist_table');

// Banla menü öğesini oluşturma
function sb_register_admin_menu() {
    add_menu_page('Ban List', 'Ban List', 'manage_options', 'sb-ban-list', 'sb_ban_list_page', 'dashicons-shield-alt', 6);
}
add_action('admin_menu', 'sb_register_admin_menu');

// Banla sayfasını oluşturma
function sb_ban_list_page() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'sb_banlist';

    if (isset($_POST['unban_user'])) {
        $user_id = intval($_POST['unban_user']);
        $wpdb->delete($table_name, array('id' => $user_id));
    }

    $results = $wpdb->get_results("SELECT * FROM $table_name");

    echo '<div class="wrap"><h1>Ban List</h1>';
    echo '<table class="wp-list-table widefat fixed striped">';
    echo '<thead><tr><th>ID</th><th>EPosta</th><th>IP Adresi</th><th>Denemeleri</th><th>Banlandığı Tarih </th><th>İşlem</th></tr></thead><tbody>';
    foreach ($results as $row) {
        echo '<tr>';
        echo '<td>' . $row->id . '</td>';
        echo '<td>' . $row->user_email . '</td>';
        echo '<td>' . $row->user_ip . '</td>';
        echo '<td>' . $row->attempt_count . '</td>';
        echo '<td>' . $row->banned_at . '</td>';
        echo '<td><form method="POST" action=""><button type="submit" name="unban_user" value="' . $row->id . '">Unban</button></form></td>';
        echo '</tr>';
    }
    echo '</tbody></table></div>';
}

// Yorum yönetim sayfasına yeni sütun ekleme
function sb_add_ban_column($columns) {
    $columns['ban_user'] = 'Banla';
    return $columns;
}
add_filter('manage_edit-comments_columns', 'sb_add_ban_column');

function sb_ban_column_content($column, $comment_ID) {
    if ($column == 'ban_user') {
        $comment = get_comment($comment_ID);
        $ban_url = admin_url('admin-ajax.php?action=sb_ban_user&comment_id=' . $comment_ID);
        echo '<a href="' . $ban_url . '" style="color: white; background-color: red; padding: 3px 6px; border-radius: 3px; text-decoration: none;">Banla</a>';
    }
}
add_action('manage_comments_custom_column', 'sb_ban_column_content', 10, 2);

function sb_ban_user() {
    global $wpdb;
    $comment_id = intval($_GET['comment_id']);
    $comment = get_comment($comment_id);

    if ($comment) {
        $table_name = $wpdb->prefix . 'sb_banlist';
        $user_ip = $comment->comment_author_IP;
        $user_email = $comment->comment_author_email;

        // IP adresinin zaten banlı olup olmadığını kontrol etme
        $banned_user = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE user_ip = %s", $user_ip));

        if ($banned_user) {
            // Banlanan kullanıcının deneme sayısını artır
            $wpdb->update(
                $table_name,
                array('attempt_count' => $banned_user->attempt_count + 1),
                array('id' => $banned_user->id)
            );

            // Banlı olduğunda bir parametre ile geri yönlendirme
            wp_redirect(add_query_arg('ban_error', '1', $_SERVER['HTTP_REFERER']));
            exit();
        } else {
            $wpdb->insert($table_name, array(
                'user_email' => $user_email,
                'user_ip' => $user_ip,
                'attempt_count' => 1
            ));

            // Yorumu spam olarak işaretleme
            wp_spam_comment($comment_id);
        }
    }

    wp_redirect($_SERVER['HTTP_REFERER']);
    exit();
}
add_action('wp_ajax_sb_ban_user', 'sb_ban_user');

// Banlı kullanıcıları engelleme
function sb_check_banned_users($commentdata) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'sb_banlist';
    $user_email = $commentdata['comment_author_email'];
    $user_ip = $commentdata['comment_author_IP'];

    $banned_user = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE user_email = %s OR user_ip = %s", $user_email, $user_ip));
    if ($banned_user) {
        wp_die('Yorum yapma izniniz engellenmiştir.');
    }

    return $commentdata;
}
add_filter('preprocess_comment', 'sb_check_banned_users');

// Hata mesajını göstermek için JavaScript ekleme
function sb_admin_notice() {
    if (isset($_GET['ban_error']) && $_GET['ban_error'] == '1') {
        echo '<div class="notice notice-error is-dismissible"><p>Bu IP adresi zaten ban listesinde.</p></div>';
        echo '<script type="text/javascript">setTimeout(function() { document.querySelector(".notice.is-dismissible").style.display = "none"; }, 5000);</script>';
    }
}
add_action('admin_notices', 'sb_admin_notice');
